DevMapHash

Struct DevMapHash 

pub struct DevMapHash { /* private fields */ }
A map of network devices.

XDP programs can use this map to redirect packets to other network devices. It is similar to DevMap, but is an hash map rather than an array. Keys do not need to be contiguous nor start at zero, but there is a hashing cost to every lookup.

Minimum kernel version

The minimum kernel version required to use this feature is 5.4.

Examples

use aya_ebpf::{bindings::xdp_action, macros::{map, xdp}, maps::DevMapHash, programs::XdpContext};

#[map]
static MAP: DevMapHash = DevMapHash::with_max_entries(1, 0);

#[xdp]
fn xdp(_ctx: XdpContext) -> u32 {
    MAP.redirect(42, xdp_action::XDP_PASS as u64).unwrap_or(xdp_action::XDP_DROP)
}

Implementations

Source

impl DevMapHash

pub const fn with_max_entries(max_entries: u32, flags: u32) -> DevMapHash

Creates a DevMapHash with a set maximum number of elements.

Examples
use aya_ebpf::{macros::map, maps::DevMapHash};

#[map]
static MAP: DevMapHash = DevMapHash::with_max_entries(8, 0);
pub const fn pinned(max_entries: u32, flags: u32) -> DevMapHash

Creates a DevMapHash with a set maximum number of elements that can be pinned to the BPF File System (bpffs).

Examples
use aya_ebpf::{macros::map, maps::DevMapHash};

#[map]
static MAP: DevMapHash = DevMapHash::pinned(8, 0);
pub fn get(&self, key: u32) -> Option<DevMapValue>

Retrieves the interface index with key in the map.

To actually redirect a packet, see DevMapHash::redirect.

Examples
use aya_ebpf::{macros::map, maps::DevMapHash};

#[map]
static MAP: DevMapHash = DevMapHash::with_max_entries(1, 0);

let target_if_index = MAP.get(42).unwrap().if_index;

// redirect to ifindex
pub fn redirect(&self, key: u32, flags: u64) -> Result<u32, u32>

Redirects the current packet on the interface at key.

The lower two bits of flags are used for the return code if the map lookup fails, which can be used as the XDP program’s return code if a CPU cannot be found.

Examples
use aya_ebpf::{bindings::xdp_action, macros::{map, xdp}, maps::DevMapHash, programs::XdpContext};

#[map]
static MAP: DevMapHash = DevMapHash::with_max_entries(8, 0);

#[xdp]
fn xdp(_ctx: XdpContext) -> u32 {
    MAP.redirect(7, 0).unwrap_or(xdp_action::XDP_DROP)
}